-------------------------------------------------------------------------------
-- system.vhd
-------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

library UNISIM;
use UNISIM.VCOMPONENTS.ALL;

entity system is
  port (
    sys_reset : in std_logic;
    sys_clk : in std_logic;
    rx : in std_logic;
    tx : out std_logic
  );
end system;

architecture STRUCTURE of system is

  attribute box_type : STRING;

  component xil_sat_1_wrapper is
    port (
      Clk : in std_logic;
      Reset : in std_logic;
      FSL_S_CLK : out std_logic;
      FSL_S_READ : out std_logic;
      FSL_S_DATA : in std_logic_vector(0 to 31);
      FSL_S_CONTROL : in std_logic;
      FSL_S_EXISTS : in std_logic;
      FSL_M_CLK : out std_logic;
      FSL_M_WRITE : out std_logic;
      FSL_M_DATA : out std_logic_vector(0 to 31);
      FSL_M_CONTROL : out std_logic;
      FSL_M_FULL : in std_logic
    );
  end component;

  attribute box_type of xil_sat_1_wrapper: component is "black_box";

  component opb_bus_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : out std_logic;
      SYS_Rst : in std_logic;
      Debug_SYS_Rst : in std_logic;
      WDT_Rst : in std_logic;
      M_ABus : in std_logic_vector(0 to 63);
      M_BE : in std_logic_vector(0 to 7);
      M_beXfer : in std_logic_vector(0 to 1);
      M_busLock : in std_logic_vector(0 to 1);
      M_DBus : in std_logic_vector(0 to 63);
      M_DBusEn : in std_logic_vector(0 to 1);
      M_DBusEn32_63 : in std_logic_vector(0 to 1);
      M_dwXfer : in std_logic_vector(0 to 1);
      M_fwXfer : in std_logic_vector(0 to 1);
      M_hwXfer : in std_logic_vector(0 to 1);
      M_request : in std_logic_vector(0 to 1);
      M_RNW : in std_logic_vector(0 to 1);
      M_select : in std_logic_vector(0 to 1);
      M_seqAddr : in std_logic_vector(0 to 1);
      Sl_beAck : in std_logic_vector(0 to 1);
      Sl_DBus : in std_logic_vector(0 to 63);
      Sl_DBusEn : in std_logic_vector(0 to 1);
      Sl_DBusEn32_63 : in std_logic_vector(0 to 1);
      Sl_errAck : in std_logic_vector(0 to 1);
      Sl_dwAck : in std_logic_vector(0 to 1);
      Sl_fwAck : in std_logic_vector(0 to 1);
      Sl_hwAck : in std_logic_vector(0 to 1);
      Sl_retry : in std_logic_vector(0 to 1);
      Sl_toutSup : in std_logic_vector(0 to 1);
      Sl_xferAck : in std_logic_vector(0 to 1);
      OPB_MRequest : out std_logic_vector(0 to 1);
      OPB_ABus : out std_logic_vector(0 to 31);
      OPB_BE : out std_logic_vector(0 to 3);
      OPB_beXfer : out std_logic;
      OPB_beAck : out std_logic;
      OPB_busLock : out std_logic;
      OPB_rdDBus : out std_logic_vector(0 to 31);
      OPB_wrDBus : out std_logic_vector(0 to 31);
      OPB_DBus : out std_logic_vector(0 to 31);
      OPB_errAck : out std_logic;
      OPB_dwAck : out std_logic;
      OPB_dwXfer : out std_logic;
      OPB_fwAck : out std_logic;
      OPB_fwXfer : out std_logic;
      OPB_hwAck : out std_logic;
      OPB_hwXfer : out std_logic;
      OPB_MGrant : out std_logic_vector(0 to 1);
      OPB_pendReq : out std_logic_vector(0 to 1);
      OPB_retry : out std_logic;
      OPB_RNW : out std_logic;
      OPB_select : out std_logic;
      OPB_seqAddr : out std_logic;
      OPB_timeout : out std_logic;
      OPB_toutSup : out std_logic;
      OPB_xferAck : out std_logic
    );
  end component;

  attribute box_type of opb_bus_wrapper: component is "black_box";

  component myuart_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      Interrupt : out std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      OPB_DBus : in std_logic_vector(0 to 31);
      UART_DBus : out std_logic_vector(0 to 31);
      UART_errAck : out std_logic;
      UART_retry : out std_logic;
      UART_toutSup : out std_logic;
      UART_xferAck : out std_logic;
      RX : in std_logic;
      TX : out std_logic
    );
  end component;

  attribute box_type of myuart_wrapper: component is "black_box";

  component mymdm_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      Interrupt : out std_logic;
      Debug_SYS_Rst : out std_logic;
      Debug_Rst : out std_logic;
      Ext_BRK : out std_logic;
      Ext_NM_BRK : out std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      OPB_DBus : in std_logic_vector(0 to 31);
      MDM_DBus : out std_logic_vector(0 to 31);
      MDM_errAck : out std_logic;
      MDM_retry : out std_logic;
      MDM_toutSup : out std_logic;
      MDM_xferAck : out std_logic;
      Dbg_Clk_0 : out std_logic;
      Dbg_TDI_0 : out std_logic;
      Dbg_TDO_0 : in std_logic;
      Dbg_Reg_En_0 : out std_logic_vector(0 to 4);
      Dbg_Capture_0 : out std_logic;
      Dbg_Update_0 : out std_logic;
      Dbg_Clk_1 : out std_logic;
      Dbg_TDI_1 : out std_logic;
      Dbg_TDO_1 : in std_logic;
      Dbg_Reg_En_1 : out std_logic_vector(0 to 4);
      Dbg_Capture_1 : out std_logic;
      Dbg_Update_1 : out std_logic;
      Dbg_Clk_2 : out std_logic;
      Dbg_TDI_2 : out std_logic;
      Dbg_TDO_2 : in std_logic;
      Dbg_Reg_En_2 : out std_logic_vector(0 to 4);
      Dbg_Capture_2 : out std_logic;
      Dbg_Update_2 : out std_logic;
      Dbg_Clk_3 : out std_logic;
      Dbg_TDI_3 : out std_logic;
      Dbg_TDO_3 : in std_logic;
      Dbg_Reg_En_3 : out std_logic_vector(0 to 4);
      Dbg_Capture_3 : out std_logic;
      Dbg_Update_3 : out std_logic;
      Dbg_Clk_4 : out std_logic;
      Dbg_TDI_4 : out std_logic;
      Dbg_TDO_4 : in std_logic;
      Dbg_Reg_En_4 : out std_logic_vector(0 to 4);
      Dbg_Capture_4 : out std_logic;
      Dbg_Update_4 : out std_logic;
      Dbg_Clk_5 : out std_logic;
      Dbg_TDI_5 : out std_logic;
      Dbg_TDO_5 : in std_logic;
      Dbg_Reg_En_5 : out std_logic_vector(0 to 4);
      Dbg_Capture_5 : out std_logic;
      Dbg_Update_5 : out std_logic;
      Dbg_Clk_6 : out std_logic;
      Dbg_TDI_6 : out std_logic;
      Dbg_TDO_6 : in std_logic;
      Dbg_Reg_En_6 : out std_logic_vector(0 to 4);
      Dbg_Capture_6 : out std_logic;
      Dbg_Update_6 : out std_logic;
      Dbg_Clk_7 : out std_logic;
      Dbg_TDI_7 : out std_logic;
      Dbg_TDO_7 : in std_logic;
      Dbg_Reg_En_7 : out std_logic_vector(0 to 4);
      Dbg_Capture_7 : out std_logic;
      Dbg_Update_7 : out std_logic;
      bscan_tdi : out std_logic;
      bscan_reset : out std_logic;
      bscan_shift : out std_logic;
      bscan_update : out std_logic;
      bscan_capture : out std_logic;
      bscan_sel1 : out std_logic;
      bscan_drck1 : out std_logic;
      bscan_tdo1 : in std_logic;
      FSL0_S_CLK : out std_logic;
      FSL0_S_READ : out std_logic;
      FSL0_S_DATA : in std_logic_vector(0 to 31);
      FSL0_S_CONTROL : in std_logic;
      FSL0_S_EXISTS : in std_logic;
      FSL0_M_CLK : out std_logic;
      FSL0_M_WRITE : out std_logic;
      FSL0_M_DATA : out std_logic_vector(0 to 31);
      FSL0_M_CONTROL : out std_logic;
      FSL0_M_FULL : in std_logic
    );
  end component;

  attribute box_type of mymdm_wrapper: component is "black_box";

  component mblaze_wrapper is
    port (
      CLK : in std_logic;
      RESET : in std_logic;
      INTERRUPT : in std_logic;
      DEBUG_RST : in std_logic;
      EXT_BRK : in std_logic;
      EXT_NM_BRK : in std_logic;
      DBG_STOP : in std_logic;
      INSTR : in std_logic_vector(0 to 31);
      I_ADDRTAG : out std_logic_vector(0 to 3);
      IREADY : in std_logic;
      IWAIT : in std_logic;
      INSTR_ADDR : out std_logic_vector(0 to 31);
      IFETCH : out std_logic;
      I_AS : out std_logic;
      DATA_READ : in std_logic_vector(0 to 31);
      DREADY : in std_logic;
      DWAIT : in std_logic;
      DATA_WRITE : out std_logic_vector(0 to 31);
      DATA_ADDR : out std_logic_vector(0 to 31);
      D_ADDRTAG : out std_logic_vector(0 to 3);
      D_AS : out std_logic;
      READ_STROBE : out std_logic;
      WRITE_STROBE : out std_logic;
      BYTE_ENABLE : out std_logic_vector(0 to 3);
      DM_ABUS : out std_logic_vector(0 to 31);
      DM_BE : out std_logic_vector(0 to 3);
      DM_BUSLOCK : out std_logic;
      DM_DBUS : out std_logic_vector(0 to 31);
      DM_REQUEST : out std_logic;
      DM_RNW : out std_logic;
      DM_SELECT : out std_logic;
      DM_SEQADDR : out std_logic;
      DOPB_DBUS : in std_logic_vector(0 to 31);
      DOPB_ERRACK : in std_logic;
      DOPB_MGRANT : in std_logic;
      DOPB_RETRY : in std_logic;
      DOPB_TIMEOUT : in std_logic;
      DOPB_XFERACK : in std_logic;
      IM_ABUS : out std_logic_vector(0 to 31);
      IM_BE : out std_logic_vector(0 to 3);
      IM_BUSLOCK : out std_logic;
      IM_DBUS : out std_logic_vector(0 to 31);
      IM_REQUEST : out std_logic;
      IM_RNW : out std_logic;
      IM_SELECT : out std_logic;
      IM_SEQADDR : out std_logic;
      IOPB_DBUS : in std_logic_vector(0 to 31);
      IOPB_ERRACK : in std_logic;
      IOPB_MGRANT : in std_logic;
      IOPB_RETRY : in std_logic;
      IOPB_TIMEOUT : in std_logic;
      IOPB_XFERACK : in std_logic;
      DBG_CLK : in std_logic;
      DBG_TDI : in std_logic;
      DBG_TDO : out std_logic;
      DBG_REG_EN : in std_logic_vector(0 to 4);
      DBG_CAPTURE : in std_logic;
      DBG_UPDATE : in std_logic;
      VALID_INSTR : out std_logic;
      PC_EX : out std_logic_vector(0 to 31);
      REG_WRITE : out std_logic;
      REG_ADDR : out std_logic_vector(0 to 4);
      MSR_REG : out std_logic_vector(0 to 9);
      NEW_REG_VALUE : out std_logic_vector(0 to 31);
      PIPE_RUNNING : out std_logic;
      INTERRUPT_TAKEN : out std_logic;
      JUMP_TAKEN : out std_logic;
      PREFETCH_ADDR : out std_logic_vector(0 to 3);
      MB_Halted : out std_logic;
      Trace_Branch_Instr : out std_logic;
      Trace_Delay_Slot : out std_logic;
      Trace_Data_Address : out std_logic_vector(0 to 31);
      Trace_AS : out std_logic;
      Trace_Data_Read : out std_logic;
      Trace_Data_Write : out std_logic;
      Trace_DCache_Req : out std_logic;
      Trace_DCache_Hit : out std_logic;
      Trace_ICache_Req : out std_logic;
      Trace_ICache_Hit : out std_logic;
      Trace_Instr_EX : out std_logic_vector(0 to 31);
      FSL0_S_CLK : out std_logic;
      FSL0_S_READ : out std_logic;
      FSL0_S_DATA : in std_logic_vector(0 to 31);
      FSL0_S_CONTROL : in std_logic;
      FSL0_S_EXISTS : in std_logic;
      FSL0_M_CLK : out std_logic;
      FSL0_M_WRITE : out std_logic;
      FSL0_M_DATA : out std_logic_vector(0 to 31);
      FSL0_M_CONTROL : out std_logic;
      FSL0_M_FULL : in std_logic;
      FSL1_S_CLK : out std_logic;
      FSL1_S_READ : out std_logic;
      FSL1_S_DATA : in std_logic_vector(0 to 31);
      FSL1_S_CONTROL : in std_logic;
      FSL1_S_EXISTS : in std_logic;
      FSL1_M_CLK : out std_logic;
      FSL1_M_WRITE : out std_logic;
      FSL1_M_DATA : out std_logic_vector(0 to 31);
      FSL1_M_CONTROL : out std_logic;
      FSL1_M_FULL : in std_logic;
      FSL2_S_CLK : out std_logic;
      FSL2_S_READ : out std_logic;
      FSL2_S_DATA : in std_logic_vector(0 to 31);
      FSL2_S_CONTROL : in std_logic;
      FSL2_S_EXISTS : in std_logic;
      FSL2_M_CLK : out std_logic;
      FSL2_M_WRITE : out std_logic;
      FSL2_M_DATA : out std_logic_vector(0 to 31);
      FSL2_M_CONTROL : out std_logic;
      FSL2_M_FULL : in std_logic;
      FSL3_S_CLK : out std_logic;
      FSL3_S_READ : out std_logic;
      FSL3_S_DATA : in std_logic_vector(0 to 31);
      FSL3_S_CONTROL : in std_logic;
      FSL3_S_EXISTS : in std_logic;
      FSL3_M_CLK : out std_logic;
      FSL3_M_WRITE : out std_logic;
      FSL3_M_DATA : out std_logic_vector(0 to 31);
      FSL3_M_CONTROL : out std_logic;
      FSL3_M_FULL : in std_logic;
      FSL4_S_CLK : out std_logic;
      FSL4_S_READ : out std_logic;
      FSL4_S_DATA : in std_logic_vector(0 to 31);
      FSL4_S_CONTROL : in std_logic;
      FSL4_S_EXISTS : in std_logic;
      FSL4_M_CLK : out std_logic;
      FSL4_M_WRITE : out std_logic;
      FSL4_M_DATA : out std_logic_vector(0 to 31);
      FSL4_M_CONTROL : out std_logic;
      FSL4_M_FULL : in std_logic;
      FSL5_S_CLK : out std_logic;
      FSL5_S_READ : out std_logic;
      FSL5_S_DATA : in std_logic_vector(0 to 31);
      FSL5_S_CONTROL : in std_logic;
      FSL5_S_EXISTS : in std_logic;
      FSL5_M_CLK : out std_logic;
      FSL5_M_WRITE : out std_logic;
      FSL5_M_DATA : out std_logic_vector(0 to 31);
      FSL5_M_CONTROL : out std_logic;
      FSL5_M_FULL : in std_logic;
      FSL6_S_CLK : out std_logic;
      FSL6_S_READ : out std_logic;
      FSL6_S_DATA : in std_logic_vector(0 to 31);
      FSL6_S_CONTROL : in std_logic;
      FSL6_S_EXISTS : in std_logic;
      FSL6_M_CLK : out std_logic;
      FSL6_M_WRITE : out std_logic;
      FSL6_M_DATA : out std_logic_vector(0 to 31);
      FSL6_M_CONTROL : out std_logic;
      FSL6_M_FULL : in std_logic;
      FSL7_S_CLK : out std_logic;
      FSL7_S_READ : out std_logic;
      FSL7_S_DATA : in std_logic_vector(0 to 31);
      FSL7_S_CONTROL : in std_logic;
      FSL7_S_EXISTS : in std_logic;
      FSL7_M_CLK : out std_logic;
      FSL7_M_WRITE : out std_logic;
      FSL7_M_DATA : out std_logic_vector(0 to 31);
      FSL7_M_CONTROL : out std_logic;
      FSL7_M_FULL : in std_logic;
      ICACHE_FSL_IN_CLK : out std_logic;
      ICACHE_FSL_IN_READ : out std_logic;
      ICACHE_FSL_IN_DATA : in std_logic_vector(0 to 31);
      ICACHE_FSL_IN_CONTROL : in std_logic;
      ICACHE_FSL_IN_EXISTS : in std_logic;
      ICACHE_FSL_OUT_CLK : out std_logic;
      ICACHE_FSL_OUT_WRITE : out std_logic;
      ICACHE_FSL_OUT_DATA : out std_logic_vector(0 to 31);
      ICACHE_FSL_OUT_CONTROL : out std_logic;
      ICACHE_FSL_OUT_FULL : in std_logic;
      DCACHE_FSL_IN_CLK : out std_logic;
      DCACHE_FSL_IN_READ : out std_logic;
      DCACHE_FSL_IN_DATA : in std_logic_vector(0 to 31);
      DCACHE_FSL_IN_CONTROL : in std_logic;
      DCACHE_FSL_IN_EXISTS : in std_logic;
      DCACHE_FSL_OUT_CLK : out std_logic;
      DCACHE_FSL_OUT_WRITE : out std_logic;
      DCACHE_FSL_OUT_DATA : out std_logic_vector(0 to 31);
      DCACHE_FSL_OUT_CONTROL : out std_logic;
      DCACHE_FSL_OUT_FULL : in std_logic
    );
  end component;

  attribute box_type of mblaze_wrapper: component is "black_box";

  component ilmb_cntlr_wrapper is
    port (
      LMB_Clk : in std_logic;
      LMB_Rst : in std_logic;
      LMB_ABus : in std_logic_vector(0 to 31);
      LMB_WriteDBus : in std_logic_vector(0 to 31);
      LMB_AddrStrobe : in std_logic;
      LMB_ReadStrobe : in std_logic;
      LMB_WriteStrobe : in std_logic;
      LMB_BE : in std_logic_vector(0 to 3);
      Sl_DBus : out std_logic_vector(0 to 31);
      Sl_Ready : out std_logic;
      BRAM_Rst_A : out std_logic;
      BRAM_Clk_A : out std_logic;
      BRAM_EN_A : out std_logic;
      BRAM_WEN_A : out std_logic_vector(0 to 3);
      BRAM_Addr_A : out std_logic_vector(0 to 31);
      BRAM_Din_A : in std_logic_vector(0 to 31);
      BRAM_Dout_A : out std_logic_vector(0 to 31)
    );
  end component;

  attribute box_type of ilmb_cntlr_wrapper: component is "black_box";

  component i_lmb_wrapper is
    port (
      LMB_Clk : in std_logic;
      SYS_Rst : in std_logic;
      LMB_Rst : out std_logic;
      M_ABus : in std_logic_vector(0 to 31);
      M_ReadStrobe : in std_logic;
      M_WriteStrobe : in std_logic;
      M_AddrStrobe : in std_logic;
      M_DBus : in std_logic_vector(0 to 31);
      M_BE : in std_logic_vector(0 to 3);
      Sl_DBus : in std_logic_vector(0 to 31);
      Sl_Ready : in std_logic_vector(0 to 0);
      LMB_ABus : out std_logic_vector(0 to 31);
      LMB_ReadStrobe : out std_logic;
      LMB_WriteStrobe : out std_logic;
      LMB_AddrStrobe : out std_logic;
      LMB_ReadDBus : out std_logic_vector(0 to 31);
      LMB_WriteDBus : out std_logic_vector(0 to 31);
      LMB_Ready : out std_logic;
      LMB_BE : out std_logic_vector(0 to 3)
    );
  end component;

  attribute box_type of i_lmb_wrapper: component is "black_box";

  component i_fsl_v20_1_wrapper is
    port (
      FSL_Clk : in std_logic;
      SYS_Rst : in std_logic;
      FSL_Rst : out std_logic;
      FSL_M_Clk : in std_logic;
      FSL_M_Data : in std_logic_vector(0 to 31);
      FSL_M_Control : in std_logic;
      FSL_M_Write : in std_logic;
      FSL_M_Full : out std_logic;
      FSL_S_Clk : in std_logic;
      FSL_S_Data : out std_logic_vector(0 to 31);
      FSL_S_Control : out std_logic;
      FSL_S_Read : in std_logic;
      FSL_S_Exists : out std_logic
    );
  end component;

  attribute box_type of i_fsl_v20_1_wrapper: component is "black_box";

  component i_fsl_v20_0_wrapper is
    port (
      FSL_Clk : in std_logic;
      SYS_Rst : in std_logic;
      FSL_Rst : out std_logic;
      FSL_M_Clk : in std_logic;
      FSL_M_Data : in std_logic_vector(0 to 31);
      FSL_M_Control : in std_logic;
      FSL_M_Write : in std_logic;
      FSL_M_Full : out std_logic;
      FSL_S_Clk : in std_logic;
      FSL_S_Data : out std_logic_vector(0 to 31);
      FSL_S_Control : out std_logic;
      FSL_S_Read : in std_logic;
      FSL_S_Exists : out std_logic
    );
  end component;

  attribute box_type of i_fsl_v20_0_wrapper: component is "black_box";

  component dlmb_cntlr_wrapper is
    port (
      LMB_Clk : in std_logic;
      LMB_Rst : in std_logic;
      LMB_ABus : in std_logic_vector(0 to 31);
      LMB_WriteDBus : in std_logic_vector(0 to 31);
      LMB_AddrStrobe : in std_logic;
      LMB_ReadStrobe : in std_logic;
      LMB_WriteStrobe : in std_logic;
      LMB_BE : in std_logic_vector(0 to 3);
      Sl_DBus : out std_logic_vector(0 to 31);
      Sl_Ready : out std_logic;
      BRAM_Rst_A : out std_logic;
      BRAM_Clk_A : out std_logic;
      BRAM_EN_A : out std_logic;
      BRAM_WEN_A : out std_logic_vector(0 to 3);
      BRAM_Addr_A : out std_logic_vector(0 to 31);
      BRAM_Din_A : in std_logic_vector(0 to 31);
      BRAM_Dout_A : out std_logic_vector(0 to 31)
    );
  end component;

  attribute box_type of dlmb_cntlr_wrapper: component is "black_box";

  component d_lmb_wrapper is
    port (
      LMB_Clk : in std_logic;
      SYS_Rst : in std_logic;
      LMB_Rst : out std_logic;
      M_ABus : in std_logic_vector(0 to 31);
      M_ReadStrobe : in std_logic;
      M_WriteStrobe : in std_logic;
      M_AddrStrobe : in std_logic;
      M_DBus : in std_logic_vector(0 to 31);
      M_BE : in std_logic_vector(0 to 3);
      Sl_DBus : in std_logic_vector(0 to 31);
      Sl_Ready : in std_logic_vector(0 to 0);
      LMB_ABus : out std_logic_vector(0 to 31);
      LMB_ReadStrobe : out std_logic;
      LMB_WriteStrobe : out std_logic;
      LMB_AddrStrobe : out std_logic;
      LMB_ReadDBus : out std_logic_vector(0 to 31);
      LMB_WriteDBus : out std_logic_vector(0 to 31);
      LMB_Ready : out std_logic;
      LMB_BE : out std_logic_vector(0 to 3)
    );
  end component;

  attribute box_type of d_lmb_wrapper: component is "black_box";

  component bram_block_0_wrapper is
    port (
      BRAM_Rst_A : in std_logic;
      BRAM_Clk_A : in std_logic;
      BRAM_EN_A : in std_logic;
      BRAM_WEN_A : in std_logic_vector(0 to 3);
      BRAM_Addr_A : in std_logic_vector(0 to 31);
      BRAM_Din_A : out std_logic_vector(0 to 31);
      BRAM_Dout_A : in std_logic_vector(0 to 31);
      BRAM_Rst_B : in std_logic;
      BRAM_Clk_B : in std_logic;
      BRAM_EN_B : in std_logic;
      BRAM_WEN_B : in std_logic_vector(0 to 3);
      BRAM_Addr_B : in std_logic_vector(0 to 31);
      BRAM_Din_B : out std_logic_vector(0 to 31);
      BRAM_Dout_B : in std_logic_vector(0 to 31)
    );
  end component;

  attribute box_type of bram_block_0_wrapper: component is "black_box";

  component IBUF is
    port (
      I : in std_logic;
      O : out std_logic
    );
  end component;

  component BUFGP is
    port (
      I : in std_logic;
      O : out std_logic
    );
  end component;

  component OBUF is
    port (
      I : in std_logic;
      O : out std_logic
    );
  end component;

  -- Internal signals

  signal Dbg_Capture : std_logic;
  signal Dbg_Clk : std_logic;
  signal Dbg_Reg_En : std_logic_vector(0 to 4);
  signal Dbg_TDI : std_logic;
  signal Dbg_TDO : std_logic;
  signal Dbg_Update : std_logic;
  signal Debug_Rst : std_logic;
  signal Ext_BRK : std_logic;
  signal Ext_NM_BRK : std_logic;
  signal d_lmb_LMB_ABus : std_logic_vector(0 to 31);
  signal d_lmb_LMB_AddrStrobe : std_logic;
  signal d_lmb_LMB_BE : std_logic_vector(0 to 3);
  signal d_lmb_LMB_ReadDBus : std_logic_vector(0 to 31);
  signal d_lmb_LMB_ReadStrobe : std_logic;
  signal d_lmb_LMB_Ready : std_logic;
  signal d_lmb_LMB_WriteDBus : std_logic_vector(0 to 31);
  signal d_lmb_LMB_WriteStrobe : std_logic;
  signal d_lmb_M_ABus : std_logic_vector(0 to 31);
  signal d_lmb_M_AddrStrobe : std_logic;
  signal d_lmb_M_BE : std_logic_vector(0 to 3);
  signal d_lmb_M_DBus : std_logic_vector(0 to 31);
  signal d_lmb_M_ReadStrobe : std_logic;
  signal d_lmb_M_WriteStrobe : std_logic;
  signal d_lmb_OPB_Rst : std_logic;
  signal d_lmb_Sl_DBus : std_logic_vector(0 to 31);
  signal d_lmb_Sl_Ready : std_logic_vector(0 to 0);
  signal dlmb_port_BRAM_Addr : std_logic_vector(0 to 31);
  signal dlmb_port_BRAM_Clk : std_logic;
  signal dlmb_port_BRAM_Din : std_logic_vector(0 to 31);
  signal dlmb_port_BRAM_Dout : std_logic_vector(0 to 31);
  signal dlmb_port_BRAM_EN : std_logic;
  signal dlmb_port_BRAM_Rst : std_logic;
  signal dlmb_port_BRAM_WEN : std_logic_vector(0 to 3);
  signal i_fsl_v20_0_FSL_M_Clk : std_logic;
  signal i_fsl_v20_0_FSL_M_Control : std_logic;
  signal i_fsl_v20_0_FSL_M_Data : std_logic_vector(0 to 31);
  signal i_fsl_v20_0_FSL_M_Full : std_logic;
  signal i_fsl_v20_0_FSL_M_Write : std_logic;
  signal i_fsl_v20_0_FSL_S_CLK : std_logic;
  signal i_fsl_v20_0_FSL_S_CONTROL : std_logic;
  signal i_fsl_v20_0_FSL_S_DATA : std_logic_vector(0 to 31);
  signal i_fsl_v20_0_FSL_S_EXISTS : std_logic;
  signal i_fsl_v20_0_FSL_S_READ : std_logic;
  signal i_fsl_v20_1_FSL_M_CLK : std_logic;
  signal i_fsl_v20_1_FSL_M_CONTROL : std_logic;
  signal i_fsl_v20_1_FSL_M_DATA : std_logic_vector(0 to 31);
  signal i_fsl_v20_1_FSL_M_FULL : std_logic;
  signal i_fsl_v20_1_FSL_M_WRITE : std_logic;
  signal i_fsl_v20_1_FSL_S_Clk : std_logic;
  signal i_fsl_v20_1_FSL_S_Control : std_logic;
  signal i_fsl_v20_1_FSL_S_Data : std_logic_vector(0 to 31);
  signal i_fsl_v20_1_FSL_S_Exists : std_logic;
  signal i_fsl_v20_1_FSL_S_Read : std_logic;
  signal i_lmb_LMB_ABus : std_logic_vector(0 to 31);
  signal i_lmb_LMB_AddrStrobe : std_logic;
  signal i_lmb_LMB_BE : std_logic_vector(0 to 3);
  signal i_lmb_LMB_ReadDBus : std_logic_vector(0 to 31);
  signal i_lmb_LMB_ReadStrobe : std_logic;
  signal i_lmb_LMB_Ready : std_logic;
  signal i_lmb_LMB_WriteDBus : std_logic_vector(0 to 31);
  signal i_lmb_LMB_WriteStrobe : std_logic;
  signal i_lmb_M_ABus : std_logic_vector(0 to 31);
  signal i_lmb_M_AddrStrobe : std_logic;
  signal i_lmb_M_ReadStrobe : std_logic;
  signal i_lmb_OPB_Rst : std_logic;
  signal i_lmb_Sl_DBus : std_logic_vector(0 to 31);
  signal i_lmb_Sl_Ready : std_logic_vector(0 to 0);
  signal ilmb_port_BRAM_Addr : std_logic_vector(0 to 31);
  signal ilmb_port_BRAM_Clk : std_logic;
  signal ilmb_port_BRAM_Din : std_logic_vector(0 to 31);
  signal ilmb_port_BRAM_Dout : std_logic_vector(0 to 31);
  signal ilmb_port_BRAM_EN : std_logic;
  signal ilmb_port_BRAM_Rst : std_logic;
  signal ilmb_port_BRAM_WEN : std_logic_vector(0 to 3);
  signal net_gnd0 : std_logic;
  signal net_gnd2 : std_logic_vector(0 to 1);
  signal net_gnd32 : std_logic_vector(0 to 31);
  signal net_gnd4 : std_logic_vector(0 to 3);
  signal net_vcc2 : std_logic_vector(0 to 1);
  signal opb_bus_Debug_SYS_Rst : std_logic;
  signal opb_bus_M_ABus : std_logic_vector(0 to 63);
  signal opb_bus_M_BE : std_logic_vector(0 to 7);
  signal opb_bus_M_DBus : std_logic_vector(0 to 63);
  signal opb_bus_M_RNW : std_logic_vector(0 to 1);
  signal opb_bus_M_busLock : std_logic_vector(0 to 1);
  signal opb_bus_M_request : std_logic_vector(0 to 1);
  signal opb_bus_M_select : std_logic_vector(0 to 1);
  signal opb_bus_M_seqAddr : std_logic_vector(0 to 1);
  signal opb_bus_OPB_ABus : std_logic_vector(0 to 31);
  signal opb_bus_OPB_BE : std_logic_vector(0 to 3);
  signal opb_bus_OPB_DBus : std_logic_vector(0 to 31);
  signal opb_bus_OPB_MGrant : std_logic_vector(0 to 1);
  signal opb_bus_OPB_RNW : std_logic;
  signal opb_bus_OPB_Rst : std_logic;
  signal opb_bus_OPB_errAck : std_logic;
  signal opb_bus_OPB_retry : std_logic;
  signal opb_bus_OPB_select : std_logic;
  signal opb_bus_OPB_seqAddr : std_logic;
  signal opb_bus_OPB_timeout : std_logic;
  signal opb_bus_OPB_xferAck : std_logic;
  signal opb_bus_Sl_DBus : std_logic_vector(0 to 63);
  signal opb_bus_Sl_errAck : std_logic_vector(0 to 1);
  signal opb_bus_Sl_retry : std_logic_vector(0 to 1);
  signal opb_bus_Sl_toutSup : std_logic_vector(0 to 1);
  signal opb_bus_Sl_xferAck : std_logic_vector(0 to 1);
  signal rx_IBUF : std_logic;
  signal sys_clk_BUFGP : std_logic;
  signal sys_reset_IBUF : std_logic;
  signal tx_OBUF : std_logic;

begin

  -- Internal assignments

  net_gnd0 <= '0';
  net_gnd2(0 to 1) <= B"00";
  net_gnd32(0 to 31) <= B"00000000000000000000000000000000";
  net_gnd4(0 to 3) <= B"0000";
  net_vcc2(0 to 1) <= B"11";

  xil_sat_1 : xil_sat_1_wrapper
    port map (
      Clk => sys_clk_BUFGP,
      Reset => sys_reset_IBUF,
      FSL_S_CLK => i_fsl_v20_0_FSL_S_CLK,
      FSL_S_READ => i_fsl_v20_0_FSL_S_READ,
      FSL_S_DATA => i_fsl_v20_0_FSL_S_DATA,
      FSL_S_CONTROL => i_fsl_v20_0_FSL_S_CONTROL,
      FSL_S_EXISTS => i_fsl_v20_0_FSL_S_EXISTS,
      FSL_M_CLK => i_fsl_v20_1_FSL_M_CLK,
      FSL_M_WRITE => i_fsl_v20_1_FSL_M_WRITE,
      FSL_M_DATA => i_fsl_v20_1_FSL_M_DATA,
      FSL_M_CONTROL => i_fsl_v20_1_FSL_M_CONTROL,
      FSL_M_FULL => i_fsl_v20_1_FSL_M_FULL
    );

  opb_bus : opb_bus_wrapper
    port map (
      OPB_Clk => sys_clk_BUFGP,
      OPB_Rst => opb_bus_OPB_Rst,
      SYS_Rst => sys_reset_IBUF,
      Debug_SYS_Rst => opb_bus_Debug_SYS_Rst,
      WDT_Rst => net_gnd0,
      M_ABus => opb_bus_M_ABus,
      M_BE => opb_bus_M_BE,
      M_beXfer => net_gnd2,
      M_busLock => opb_bus_M_busLock,
      M_DBus => opb_bus_M_DBus,
      M_DBusEn => net_gnd2,
      M_DBusEn32_63 => net_vcc2,
      M_dwXfer => net_gnd2,
      M_fwXfer => net_gnd2,
      M_hwXfer => net_gnd2,
      M_request => opb_bus_M_request,
      M_RNW => opb_bus_M_RNW,
      M_select => opb_bus_M_select,
      M_seqAddr => opb_bus_M_seqAddr,
      Sl_beAck => net_gnd2,
      Sl_DBus => opb_bus_Sl_DBus,
      Sl_DBusEn => net_vcc2,
      Sl_DBusEn32_63 => net_vcc2,
      Sl_errAck => opb_bus_Sl_errAck,
      Sl_dwAck => net_gnd2,
      Sl_fwAck => net_gnd2,
      Sl_hwAck => net_gnd2,
      Sl_retry => opb_bus_Sl_retry,
      Sl_toutSup => opb_bus_Sl_toutSup,
      Sl_xferAck => opb_bus_Sl_xferAck,
      OPB_MRequest => open,
      OPB_ABus => opb_bus_OPB_ABus,
      OPB_BE => opb_bus_OPB_BE,
      OPB_beXfer => open,
      OPB_beAck => open,
      OPB_busLock => open,
      OPB_rdDBus => open,
      OPB_wrDBus => open,
      OPB_DBus => opb_bus_OPB_DBus,
      OPB_errAck => opb_bus_OPB_errAck,
      OPB_dwAck => open,
      OPB_dwXfer => open,
      OPB_fwAck => open,
      OPB_fwXfer => open,
      OPB_hwAck => open,
      OPB_hwXfer => open,
      OPB_MGrant => opb_bus_OPB_MGrant,
      OPB_pendReq => open,
      OPB_retry => opb_bus_OPB_retry,
      OPB_RNW => opb_bus_OPB_RNW,
      OPB_select => opb_bus_OPB_select,
      OPB_seqAddr => opb_bus_OPB_seqAddr,
      OPB_timeout => opb_bus_OPB_timeout,
      OPB_toutSup => open,
      OPB_xferAck => opb_bus_OPB_xferAck
    );

  myuart : myuart_wrapper
    port map (
      OPB_Clk => sys_clk_BUFGP,
      OPB_Rst => opb_bus_OPB_Rst,
      Interrupt => open,
      OPB_ABus => opb_bus_OPB_ABus,
      OPB_BE => opb_bus_OPB_BE,
      OPB_RNW => opb_bus_OPB_RNW,
      OPB_select => opb_bus_OPB_select,
      OPB_seqAddr => opb_bus_OPB_seqAddr,
      OPB_DBus => opb_bus_OPB_DBus,
      UART_DBus => opb_bus_Sl_DBus(0 to 31),
      UART_errAck => opb_bus_Sl_errAck(0),
      UART_retry => opb_bus_Sl_retry(0),
      UART_toutSup => opb_bus_Sl_toutSup(0),
      UART_xferAck => opb_bus_Sl_xferAck(0),
      RX => rx_IBUF,
      TX => tx_OBUF
    );

  mymdm : mymdm_wrapper
    port map (
      OPB_Clk => sys_clk_BUFGP,
      OPB_Rst => opb_bus_OPB_Rst,
      Interrupt => open,
      Debug_SYS_Rst => opb_bus_Debug_SYS_Rst,
      Debug_Rst => Debug_Rst,
      Ext_BRK => Ext_BRK,
      Ext_NM_BRK => Ext_NM_BRK,
      OPB_ABus => opb_bus_OPB_ABus,
      OPB_BE => opb_bus_OPB_BE,
      OPB_RNW => opb_bus_OPB_RNW,
      OPB_select => opb_bus_OPB_select,
      OPB_seqAddr => opb_bus_OPB_seqAddr,
      OPB_DBus => opb_bus_OPB_DBus,
      MDM_DBus => opb_bus_Sl_DBus(32 to 63),
      MDM_errAck => opb_bus_Sl_errAck(1),
      MDM_retry => opb_bus_Sl_retry(1),
      MDM_toutSup => opb_bus_Sl_toutSup(1),
      MDM_xferAck => opb_bus_Sl_xferAck(1),
      Dbg_Clk_0 => Dbg_Clk,
      Dbg_TDI_0 => Dbg_TDI,
      Dbg_TDO_0 => Dbg_TDO,
      Dbg_Reg_En_0 => Dbg_Reg_En,
      Dbg_Capture_0 => Dbg_Capture,
      Dbg_Update_0 => Dbg_Update,
      Dbg_Clk_1 => open,
      Dbg_TDI_1 => open,
      Dbg_TDO_1 => net_gnd0,
      Dbg_Reg_En_1 => open,
      Dbg_Capture_1 => open,
      Dbg_Update_1 => open,
      Dbg_Clk_2 => open,
      Dbg_TDI_2 => open,
      Dbg_TDO_2 => net_gnd0,
      Dbg_Reg_En_2 => open,
      Dbg_Capture_2 => open,
      Dbg_Update_2 => open,
      Dbg_Clk_3 => open,
      Dbg_TDI_3 => open,
      Dbg_TDO_3 => net_gnd0,
      Dbg_Reg_En_3 => open,
      Dbg_Capture_3 => open,
      Dbg_Update_3 => open,
      Dbg_Clk_4 => open,
      Dbg_TDI_4 => open,
      Dbg_TDO_4 => net_gnd0,
      Dbg_Reg_En_4 => open,
      Dbg_Capture_4 => open,
      Dbg_Update_4 => open,
      Dbg_Clk_5 => open,
      Dbg_TDI_5 => open,
      Dbg_TDO_5 => net_gnd0,
      Dbg_Reg_En_5 => open,
      Dbg_Capture_5 => open,
      Dbg_Update_5 => open,
      Dbg_Clk_6 => open,
      Dbg_TDI_6 => open,
      Dbg_TDO_6 => net_gnd0,
      Dbg_Reg_En_6 => open,
      Dbg_Capture_6 => open,
      Dbg_Update_6 => open,
      Dbg_Clk_7 => open,
      Dbg_TDI_7 => open,
      Dbg_TDO_7 => net_gnd0,
      Dbg_Reg_En_7 => open,
      Dbg_Capture_7 => open,
      Dbg_Update_7 => open,
      bscan_tdi => open,
      bscan_reset => open,
      bscan_shift => open,
      bscan_update => open,
      bscan_capture => open,
      bscan_sel1 => open,
      bscan_drck1 => open,
      bscan_tdo1 => net_gnd0,
      FSL0_S_CLK => open,
      FSL0_S_READ => open,
      FSL0_S_DATA => net_gnd32,
      FSL0_S_CONTROL => net_gnd0,
      FSL0_S_EXISTS => net_gnd0,
      FSL0_M_CLK => open,
      FSL0_M_WRITE => open,
      FSL0_M_DATA => open,
      FSL0_M_CONTROL => open,
      FSL0_M_FULL => net_gnd0
    );

  mblaze : mblaze_wrapper
    port map (
      CLK => sys_clk_BUFGP,
      RESET => opb_bus_OPB_Rst,
      INTERRUPT => net_gnd0,
      DEBUG_RST => Debug_Rst,
      EXT_BRK => Ext_BRK,
      EXT_NM_BRK => Ext_NM_BRK,
      DBG_STOP => net_gnd0,
      INSTR => i_lmb_LMB_ReadDBus,
      I_ADDRTAG => open,
      IREADY => i_lmb_LMB_Ready,
      IWAIT => net_gnd0,
      INSTR_ADDR => i_lmb_M_ABus,
      IFETCH => i_lmb_M_ReadStrobe,
      I_AS => i_lmb_M_AddrStrobe,
      DATA_READ => d_lmb_LMB_ReadDBus,
      DREADY => d_lmb_LMB_Ready,
      DWAIT => net_gnd0,
      DATA_WRITE => d_lmb_M_DBus,
      DATA_ADDR => d_lmb_M_ABus,
      D_ADDRTAG => open,
      D_AS => d_lmb_M_AddrStrobe,
      READ_STROBE => d_lmb_M_ReadStrobe,
      WRITE_STROBE => d_lmb_M_WriteStrobe,
      BYTE_ENABLE => d_lmb_M_BE,
      DM_ABUS => opb_bus_M_ABus(0 to 31),
      DM_BE => opb_bus_M_BE(0 to 3),
      DM_BUSLOCK => opb_bus_M_busLock(0),
      DM_DBUS => opb_bus_M_DBus(0 to 31),
      DM_REQUEST => opb_bus_M_request(0),
      DM_RNW => opb_bus_M_RNW(0),
      DM_SELECT => opb_bus_M_select(0),
      DM_SEQADDR => opb_bus_M_seqAddr(0),
      DOPB_DBUS => opb_bus_OPB_DBus,
      DOPB_ERRACK => opb_bus_OPB_errAck,
      DOPB_MGRANT => opb_bus_OPB_MGrant(0),
      DOPB_RETRY => opb_bus_OPB_retry,
      DOPB_TIMEOUT => opb_bus_OPB_timeout,
      DOPB_XFERACK => opb_bus_OPB_xferAck,
      IM_ABUS => opb_bus_M_ABus(32 to 63),
      IM_BE => opb_bus_M_BE(4 to 7),
      IM_BUSLOCK => opb_bus_M_busLock(1),
      IM_DBUS => opb_bus_M_DBus(32 to 63),
      IM_REQUEST => opb_bus_M_request(1),
      IM_RNW => opb_bus_M_RNW(1),
      IM_SELECT => opb_bus_M_select(1),
      IM_SEQADDR => opb_bus_M_seqAddr(1),
      IOPB_DBUS => opb_bus_OPB_DBus,
      IOPB_ERRACK => opb_bus_OPB_errAck,
      IOPB_MGRANT => opb_bus_OPB_MGrant(1),
      IOPB_RETRY => opb_bus_OPB_retry,
      IOPB_TIMEOUT => opb_bus_OPB_timeout,
      IOPB_XFERACK => opb_bus_OPB_xferAck,
      DBG_CLK => Dbg_Clk,
      DBG_TDI => Dbg_TDI,
      DBG_TDO => Dbg_TDO,
      DBG_REG_EN => Dbg_Reg_En,
      DBG_CAPTURE => Dbg_Capture,
      DBG_UPDATE => Dbg_Update,
      VALID_INSTR => open,
      PC_EX => open,
      REG_WRITE => open,
      REG_ADDR => open,
      MSR_REG => open,
      NEW_REG_VALUE => open,
      PIPE_RUNNING => open,
      INTERRUPT_TAKEN => open,
      JUMP_TAKEN => open,
      PREFETCH_ADDR => open,
      MB_Halted => open,
      Trace_Branch_Instr => open,
      Trace_Delay_Slot => open,
      Trace_Data_Address => open,
      Trace_AS => open,
      Trace_Data_Read => open,
      Trace_Data_Write => open,
      Trace_DCache_Req => open,
      Trace_DCache_Hit => open,
      Trace_ICache_Req => open,
      Trace_ICache_Hit => open,
      Trace_Instr_EX => open,
      FSL0_S_CLK => i_fsl_v20_1_FSL_S_Clk,
      FSL0_S_READ => i_fsl_v20_1_FSL_S_Read,
      FSL0_S_DATA => i_fsl_v20_1_FSL_S_Data,
      FSL0_S_CONTROL => i_fsl_v20_1_FSL_S_Control,
      FSL0_S_EXISTS => i_fsl_v20_1_FSL_S_Exists,
      FSL0_M_CLK => i_fsl_v20_0_FSL_M_Clk,
      FSL0_M_WRITE => i_fsl_v20_0_FSL_M_Write,
      FSL0_M_DATA => i_fsl_v20_0_FSL_M_Data,
      FSL0_M_CONTROL => i_fsl_v20_0_FSL_M_Control,
      FSL0_M_FULL => i_fsl_v20_0_FSL_M_Full,
      FSL1_S_CLK => open,
      FSL1_S_READ => open,
      FSL1_S_DATA => net_gnd32,
      FSL1_S_CONTROL => net_gnd0,
      FSL1_S_EXISTS => net_gnd0,
      FSL1_M_CLK => open,
      FSL1_M_WRITE => open,
      FSL1_M_DATA => open,
      FSL1_M_CONTROL => open,
      FSL1_M_FULL => net_gnd0,
      FSL2_S_CLK => open,
      FSL2_S_READ => open,
      FSL2_S_DATA => net_gnd32,
      FSL2_S_CONTROL => net_gnd0,
      FSL2_S_EXISTS => net_gnd0,
      FSL2_M_CLK => open,
      FSL2_M_WRITE => open,
      FSL2_M_DATA => open,
      FSL2_M_CONTROL => open,
      FSL2_M_FULL => net_gnd0,
      FSL3_S_CLK => open,
      FSL3_S_READ => open,
      FSL3_S_DATA => net_gnd32,
      FSL3_S_CONTROL => net_gnd0,
      FSL3_S_EXISTS => net_gnd0,
      FSL3_M_CLK => open,
      FSL3_M_WRITE => open,
      FSL3_M_DATA => open,
      FSL3_M_CONTROL => open,
      FSL3_M_FULL => net_gnd0,
      FSL4_S_CLK => open,
      FSL4_S_READ => open,
      FSL4_S_DATA => net_gnd32,
      FSL4_S_CONTROL => net_gnd0,
      FSL4_S_EXISTS => net_gnd0,
      FSL4_M_CLK => open,
      FSL4_M_WRITE => open,
      FSL4_M_DATA => open,
      FSL4_M_CONTROL => open,
      FSL4_M_FULL => net_gnd0,
      FSL5_S_CLK => open,
      FSL5_S_READ => open,
      FSL5_S_DATA => net_gnd32,
      FSL5_S_CONTROL => net_gnd0,
      FSL5_S_EXISTS => net_gnd0,
      FSL5_M_CLK => open,
      FSL5_M_WRITE => open,
      FSL5_M_DATA => open,
      FSL5_M_CONTROL => open,
      FSL5_M_FULL => net_gnd0,
      FSL6_S_CLK => open,
      FSL6_S_READ => open,
      FSL6_S_DATA => net_gnd32,
      FSL6_S_CONTROL => net_gnd0,
      FSL6_S_EXISTS => net_gnd0,
      FSL6_M_CLK => open,
      FSL6_M_WRITE => open,
      FSL6_M_DATA => open,
      FSL6_M_CONTROL => open,
      FSL6_M_FULL => net_gnd0,
      FSL7_S_CLK => open,
      FSL7_S_READ => open,
      FSL7_S_DATA => net_gnd32,
      FSL7_S_CONTROL => net_gnd0,
      FSL7_S_EXISTS => net_gnd0,
      FSL7_M_CLK => open,
      FSL7_M_WRITE => open,
      FSL7_M_DATA => open,
      FSL7_M_CONTROL => open,
      FSL7_M_FULL => net_gnd0,
      ICACHE_FSL_IN_CLK => open,
      ICACHE_FSL_IN_READ => open,
      ICACHE_FSL_IN_DATA => net_gnd32,
      ICACHE_FSL_IN_CONTROL => net_gnd0,
      ICACHE_FSL_IN_EXISTS => net_gnd0,
      ICACHE_FSL_OUT_CLK => open,
      ICACHE_FSL_OUT_WRITE => open,
      ICACHE_FSL_OUT_DATA => open,
      ICACHE_FSL_OUT_CONTROL => open,
      ICACHE_FSL_OUT_FULL => net_gnd0,
      DCACHE_FSL_IN_CLK => open,
      DCACHE_FSL_IN_READ => open,
      DCACHE_FSL_IN_DATA => net_gnd32,
      DCACHE_FSL_IN_CONTROL => net_gnd0,
      DCACHE_FSL_IN_EXISTS => net_gnd0,
      DCACHE_FSL_OUT_CLK => open,
      DCACHE_FSL_OUT_WRITE => open,
      DCACHE_FSL_OUT_DATA => open,
      DCACHE_FSL_OUT_CONTROL => open,
      DCACHE_FSL_OUT_FULL => net_gnd0
    );

  ilmb_cntlr : ilmb_cntlr_wrapper
    port map (
      LMB_Clk => sys_clk_BUFGP,
      LMB_Rst => i_lmb_OPB_Rst,
      LMB_ABus => i_lmb_LMB_ABus,
      LMB_WriteDBus => i_lmb_LMB_WriteDBus,
      LMB_AddrStrobe => i_lmb_LMB_AddrStrobe,
      LMB_ReadStrobe => i_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => i_lmb_LMB_WriteStrobe,
      LMB_BE => i_lmb_LMB_BE,
      Sl_DBus => i_lmb_Sl_DBus,
      Sl_Ready => i_lmb_Sl_Ready(0),
      BRAM_Rst_A => ilmb_port_BRAM_Rst,
      BRAM_Clk_A => ilmb_port_BRAM_Clk,
      BRAM_EN_A => ilmb_port_BRAM_EN,
      BRAM_WEN_A => ilmb_port_BRAM_WEN,
      BRAM_Addr_A => ilmb_port_BRAM_Addr,
      BRAM_Din_A => ilmb_port_BRAM_Din,
      BRAM_Dout_A => ilmb_port_BRAM_Dout
    );

  i_lmb : i_lmb_wrapper
    port map (
      LMB_Clk => sys_clk_BUFGP,
      SYS_Rst => sys_reset_IBUF,
      LMB_Rst => i_lmb_OPB_Rst,
      M_ABus => i_lmb_M_ABus,
      M_ReadStrobe => i_lmb_M_ReadStrobe,
      M_WriteStrobe => net_gnd0,
      M_AddrStrobe => i_lmb_M_AddrStrobe,
      M_DBus => net_gnd32,
      M_BE => net_gnd4,
      Sl_DBus => i_lmb_Sl_DBus,
      Sl_Ready => i_lmb_Sl_Ready(0 to 0),
      LMB_ABus => i_lmb_LMB_ABus,
      LMB_ReadStrobe => i_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => i_lmb_LMB_WriteStrobe,
      LMB_AddrStrobe => i_lmb_LMB_AddrStrobe,
      LMB_ReadDBus => i_lmb_LMB_ReadDBus,
      LMB_WriteDBus => i_lmb_LMB_WriteDBus,
      LMB_Ready => i_lmb_LMB_Ready,
      LMB_BE => i_lmb_LMB_BE
    );

  i_fsl_v20_1 : i_fsl_v20_1_wrapper
    port map (
      FSL_Clk => sys_clk_BUFGP,
      SYS_Rst => net_gnd0,
      FSL_Rst => open,
      FSL_M_Clk => i_fsl_v20_1_FSL_M_CLK,
      FSL_M_Data => i_fsl_v20_1_FSL_M_DATA,
      FSL_M_Control => i_fsl_v20_1_FSL_M_CONTROL,
      FSL_M_Write => i_fsl_v20_1_FSL_M_WRITE,
      FSL_M_Full => i_fsl_v20_1_FSL_M_FULL,
      FSL_S_Clk => i_fsl_v20_1_FSL_S_Clk,
      FSL_S_Data => i_fsl_v20_1_FSL_S_Data,
      FSL_S_Control => i_fsl_v20_1_FSL_S_Control,
      FSL_S_Read => i_fsl_v20_1_FSL_S_Read,
      FSL_S_Exists => i_fsl_v20_1_FSL_S_Exists
    );

  i_fsl_v20_0 : i_fsl_v20_0_wrapper
    port map (
      FSL_Clk => sys_clk_BUFGP,
      SYS_Rst => net_gnd0,
      FSL_Rst => open,
      FSL_M_Clk => i_fsl_v20_0_FSL_M_Clk,
      FSL_M_Data => i_fsl_v20_0_FSL_M_Data,
      FSL_M_Control => i_fsl_v20_0_FSL_M_Control,
      FSL_M_Write => i_fsl_v20_0_FSL_M_Write,
      FSL_M_Full => i_fsl_v20_0_FSL_M_Full,
      FSL_S_Clk => i_fsl_v20_0_FSL_S_CLK,
      FSL_S_Data => i_fsl_v20_0_FSL_S_DATA,
      FSL_S_Control => i_fsl_v20_0_FSL_S_CONTROL,
      FSL_S_Read => i_fsl_v20_0_FSL_S_READ,
      FSL_S_Exists => i_fsl_v20_0_FSL_S_EXISTS
    );

  dlmb_cntlr : dlmb_cntlr_wrapper
    port map (
      LMB_Clk => sys_clk_BUFGP,
      LMB_Rst => d_lmb_OPB_Rst,
      LMB_ABus => d_lmb_LMB_ABus,
      LMB_WriteDBus => d_lmb_LMB_WriteDBus,
      LMB_AddrStrobe => d_lmb_LMB_AddrStrobe,
      LMB_ReadStrobe => d_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => d_lmb_LMB_WriteStrobe,
      LMB_BE => d_lmb_LMB_BE,
      Sl_DBus => d_lmb_Sl_DBus,
      Sl_Ready => d_lmb_Sl_Ready(0),
      BRAM_Rst_A => dlmb_port_BRAM_Rst,
      BRAM_Clk_A => dlmb_port_BRAM_Clk,
      BRAM_EN_A => dlmb_port_BRAM_EN,
      BRAM_WEN_A => dlmb_port_BRAM_WEN,
      BRAM_Addr_A => dlmb_port_BRAM_Addr,
      BRAM_Din_A => dlmb_port_BRAM_Din,
      BRAM_Dout_A => dlmb_port_BRAM_Dout
    );

  d_lmb : d_lmb_wrapper
    port map (
      LMB_Clk => sys_clk_BUFGP,
      SYS_Rst => sys_reset_IBUF,
      LMB_Rst => d_lmb_OPB_Rst,
      M_ABus => d_lmb_M_ABus,
      M_ReadStrobe => d_lmb_M_ReadStrobe,
      M_WriteStrobe => d_lmb_M_WriteStrobe,
      M_AddrStrobe => d_lmb_M_AddrStrobe,
      M_DBus => d_lmb_M_DBus,
      M_BE => d_lmb_M_BE,
      Sl_DBus => d_lmb_Sl_DBus,
      Sl_Ready => d_lmb_Sl_Ready(0 to 0),
      LMB_ABus => d_lmb_LMB_ABus,
      LMB_ReadStrobe => d_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => d_lmb_LMB_WriteStrobe,
      LMB_AddrStrobe => d_lmb_LMB_AddrStrobe,
      LMB_ReadDBus => d_lmb_LMB_ReadDBus,
      LMB_WriteDBus => d_lmb_LMB_WriteDBus,
      LMB_Ready => d_lmb_LMB_Ready,
      LMB_BE => d_lmb_LMB_BE
    );

  bram_block_0 : bram_block_0_wrapper
    port map (
      BRAM_Rst_A => ilmb_port_BRAM_Rst,
      BRAM_Clk_A => ilmb_port_BRAM_Clk,
      BRAM_EN_A => ilmb_port_BRAM_EN,
      BRAM_WEN_A => ilmb_port_BRAM_WEN,
      BRAM_Addr_A => ilmb_port_BRAM_Addr,
      BRAM_Din_A => ilmb_port_BRAM_Din,
      BRAM_Dout_A => ilmb_port_BRAM_Dout,
      BRAM_Rst_B => dlmb_port_BRAM_Rst,
      BRAM_Clk_B => dlmb_port_BRAM_Clk,
      BRAM_EN_B => dlmb_port_BRAM_EN,
      BRAM_WEN_B => dlmb_port_BRAM_WEN,
      BRAM_Addr_B => dlmb_port_BRAM_Addr,
      BRAM_Din_B => dlmb_port_BRAM_Din,
      BRAM_Dout_B => dlmb_port_BRAM_Dout
    );

  ibuf_0 : IBUF
    port map (
      I => sys_reset,
      O => sys_reset_IBUF
    );

  bufgp_1 : BUFGP
    port map (
      I => sys_clk,
      O => sys_clk_BUFGP
    );

  ibuf_2 : IBUF
    port map (
      I => rx,
      O => rx_IBUF
    );

  obuf_3 : OBUF
    port map (
      I => tx_OBUF,
      O => tx
    );

end architecture STRUCTURE;
