`define STATE_COUNT 6:0
`define INIT  0
`define REC1  1
`define REC2  2
`define REC3  3 
`define SEND1 4
`define SEND2 5
`define SEND3 6 
module system_controller (clk, reset_b, data_exists, data_in, shifted_data, data_out_write, select_data, data_feed_enable, load , full) ;

	input clk, reset_b, data_exists, full;
	input [31:0] data_in ;
	output shifted_data, data_out_write, data_feed_enable, load;
	output [4:0] select_data;
	
	reg [`STATE_COUNT] state, next_state;
	
	
//intermediate wires and registers
	reg [31:0] shift_register;
	reg [4:0] rec_counter1, rec_counter2, send_counter; 
	wire reached_32, reached_32_32, reached_24; 
	
	wire init_state = state[`INIT] ;
	wire send_state = state[`SEND2] ;
	
	always @ (posedge clk or negedge reset_b)
		if (~reset_b)
			state <= 1;
		else 
			state <= next_state ;
	
	always @ (state or data_exists or reached_32 or reached_32_32 or reached_24 or full )
		begin
			next_state = 0 ;
			casex(1)
				state[`INIT]: 
					if ( data_exists )
						next_state[`REC1] <= 1 ;
					else 
						next_state[`INIT] <= 1 ;

				state[`REC1]:	next_state[`REC2] <= 1 ;

				state[`REC2]: 
					if ( reached_32 )
						next_state[`REC3] <= 1 ;
					else 
						next_state[`REC2] <= 1 ;

				state[`REC3]: 
					if ( reached_32_32 )
						next_state[`SEND1] <= 1 ;
					else if ( data_exists )
						next_state[`REC1] <= 1 ;
					else
						next_state[`REC3] <= 1 ;
						
				state[`SEND1]: 
					next_state[`SEND2] <= 1 ;

				state[`SEND2]: 
					next_state[`SEND3] <= 1 ;

				state[`SEND3]: 
					if ( reached_24 )
						next_state[`INIT] <= 1 ;
					else if (~full)
						next_state[`SEND1] <= 1 ;
					else
						next_state[`SEND3]<= 1 ;
				default:next_state[`INIT]= 1;
			endcase
		end
		

//Shift Register
	always @(posedge clk or negedge reset_b)
		if ( ~reset_b ) 
			shift_register <= 32'h0 ;
		else if ( load )
			shift_register <= data_in ;
		else if ( data_feed_enable )
			shift_register <= {1'b0,shift_register[31:1]} ;

//Recieve Counter #1
	always @(posedge clk or negedge reset_b )
		if ( ~reset_b ) 
			rec_counter1 <= 0 ;
		else if ( load )
			rec_counter1 <= 0 ;
		else if ( data_feed_enable )
			rec_counter1 <= rec_counter1 + 1 ;

//Recieve Counter #2
	always @(posedge clk or negedge reset_b )
		if ( ~reset_b ) 
			rec_counter2 <= 5'b11111 ;
		else if ( init_state )
			rec_counter2 <= 5'b11111 ;
		else if ( load )
			rec_counter2 <= rec_counter2 + 1 ;

//Send Counter
	always @(posedge clk or negedge reset_b )
		if ( ~reset_b ) 
			send_counter <= 0 ;
		else if ( init_state )
			send_counter <= 0 ;
		else if ( send_state )
			send_counter <= send_counter + 1 ;

//Wires
	assign reached_24 = ( send_counter==5'd23 ) ? 1 : 0 ;
	assign reached_32 = ( rec_counter1==5'd31 ) ? 1 : 0 ;
	assign reached_32_32 = ( rec_counter2==5'd31 ) ? 1 : 0 ;

//Output Assignment
	assign shifted_data = shift_register[0] ;
	assign select_data = send_counter ;
	assign data_out_write = state[`SEND1] ;
	assign data_feed_enable = state[`REC2] ;
	assign load = state[`REC1] ;
	
endmodule