-- 17-12-1998:  : First implemetation
-- 27-08-1999:  : Moved trace function from iu 
-- 26-09-1999:  : Release 1.0
------------------------------------------------------------------------------  

library IEEE;
use IEEE.Std_Logic_1164.all;
-- use IEEE.Std_Logic_arith.all;
-- use IEEE.std_logic_unsigned.conv_integer;
use STD.TEXTIO.all;

-- library microblaze_v2_00_a;
-- use microblaze_v2_00_a.all;

package debug is

--type debug_info is record
-- op 	: std_logic_vector(0 to 31);
-- pc 	: std_logic_vector(0 to 31);
--end record;


subtype nibble is std_logic_vector(0 to 3);
subtype reg    is std_logic_vector(0 to 4);

-- Dissasembler for the MicroBlaze
function disas(inst : std_logic_vector(0 to 31)) return string; 
function tohex(n:nibble) return string;
function todec(r:reg) return string;
procedure print(s : string);

end debug;

package body debug is

function tohex(n:nibble) return string is
begin
  case n is
  when "0000" => return("0");
  when "0001" => return("1");
  when "0010" => return("2");
  when "0011" => return("3");
  when "0100" => return("4");
  when "0101" => return("5");
  when "0110" => return("6");
  when "0111" => return("7");
  when "1000" => return("8");
  when "1001" => return("9");
  when "1010" => return("a");
  when "1011" => return("b");
  when "1100" => return("c");
  when "1101" => return("d");
  when "1110" => return("e");
  when "1111" => return("f");
  when others => return("X");
  end case;
end;


function todec(r:reg) return string is
begin
  case r is
  when "00000" => return("0");
  when "00001" => return("1");
  when "00010" => return("2");
  when "00011" => return("3");
  when "00100" => return("4");
  when "00101" => return("5");
  when "00110" => return("6");
  when "00111" => return("7");
  when "01000" => return("8");
  when "01001" => return("9");
  when "01010" => return("10");
  when "01011" => return("11");
  when "01100" => return("12");
  when "01101" => return("13");
  when "01110" => return("14");
  when "01111" => return("15");
  when "10000" => return("16");
  when "10001" => return("17");
  when "10010" => return("18");
  when "10011" => return("19");
  when "10100" => return("20");
  when "10101" => return("21");
  when "10110" => return("22");
  when "10111" => return("23");
  when "11000" => return("24");
  when "11001" => return("25");
  when "11010" => return("26");
  when "11011" => return("27");
  when "11100" => return("28");
  when "11101" => return("29");
  when "11110" => return("30");
  when "11111" => return("31");
  when others => return("X");
  end case;
end;



------------------------------------------------------------------------------------------
-- This includes the MicroBlaze dissasembler
------------------------------------------------------------------------------------------

function disas(inst : std_logic_vector(0 to 31)) return string is
  variable op     : std_logic_vector(0 to 5);
  variable ra, rb, rd : std_logic_vector(0 to 4);
  variable addr   : std_logic_vector(0 to 31);
  variable i      : std_logic;
  variable imm : std_logic_vector(0 to 15);

 
  
begin

    op   := inst(0  to 5);
    rd   := inst(6  to 10);
    ra  := inst(11 to 15);
    rb  := inst(16 to 20);
    imm  := inst(16 to 31);
    
    case op is 	-- disassembly stage
	-- add
    	when "000000" =>
    	return("add   " & "   rd%" & todec(rd) & "   ra%" & todec(ra) & "   rb%" & todec(rb));
	when"000100" =>
	return("addk   " & "   rd%" & todec(rd) & "   ra%" & todec(ra) & "   rb%" & todec(rb));
	when"000010" =>
	return("addc   " & "   rd%" & todec(rd) & "   ra%" & todec(ra) & "   rb%" & todec(rb));
	when"000110" =>
	return("addkc   " & "   rd%" & todec(rd) & "   ra%" & todec(ra) & "   rb%" & todec(rb));
	-- addi
	when "001000" =>
    	return("addi   " & "   rd%" & todec(rd) & "   ra%" & todec(ra) & "   imm " & tohex(imm(0 to 3)) 
										  & tohex(imm(4 to 7))
										  & tohex(imm(8 to 11)) 
										  & tohex(imm(12 to 15)));
	when "001010" =>
    	return("addic   " & "   rd%" & todec(rd) & "   ra%" & todec(ra) & "   imm " & tohex(imm(0 to 3)) 
										  & tohex(imm(4 to 7))
										  & tohex(imm(8 to 11)) 
										  & tohex(imm(12 to 15)));
	when "001100" =>
    	return("addik   " & "   rd%" & todec(rd) & "   ra%" & todec(ra) & "   imm " & tohex(imm(0 to 3)) 
										  & tohex(imm(4 to 7))
										  & tohex(imm(8 to 11)) 
										  & tohex(imm(12 to 15)));
	when "001110" =>
    	return("addikc   " & "   rd%" & todec(rd) & "   ra%" & todec(ra) & "   imm " & tohex(imm(0 to 3)) 
										  & tohex(imm(4 to 7))
										  & tohex(imm(8 to 11)) 
										  & tohex(imm(12 to 15)));
	-- and
    	when "100001" =>
    	return("and   " & "   rd%" & todec(rd) & "   ra%" & todec(ra) & "   rb%" & todec(rb));
	when "101001" =>
    	return("andi   " & "   rd%" & todec(rd) & "   ra%" & todec(ra) & "   imm " & tohex(imm(0 to 3)) 
										  & tohex(imm(4 to 7))
										  & tohex(imm(8 to 11)) 
										  & tohex(imm(12 to 15)));
	when "100011" =>
    	return("andn   " & "   rd%" & todec(rd) & "   ra%" & todec(ra) & "   rb%" & todec(rb));
	when "101011" =>
    	return("andni   " & "   rd%" & todec(rd) & "   ra%" & todec(ra) & "   imm " & tohex(imm(0 to 3)) 
										  & tohex(imm(4 to 7))
										  & tohex(imm(8 to 11)) 
										  & tohex(imm(12 to 15)));
	-- beq
    	when "100111" =>
	if rd = "10000" then
    	  return("beqd   " & "   ra%" & todec(ra) & "   rb%" & todec(rb));
	elsif rd = "00000" then
	  return("beq   " & "   ra%" & todec(ra) & "   rb%" & todec(rb));
	-- bge
	elsif rd = "00101" then
    	  return("bged   " & "   ra%" & todec(ra) & "   rb%" & todec(rb));
	elsif rd = "00101" then
	  return("bge   " & "   ra%" & todec(ra) & "   rb%" & todec(rb));
	end if;

	when "101111" => 
	if rd = "00000" then
    	  return("beqi   " & "   ra%" & todec(ra) & "   imm " & tohex(imm(0 to 3)) 
							     & tohex(imm(4 to 7))
							     & tohex(imm(8 to 11)) 
							     & tohex(imm(12 to 15)));
	elsif rd = "10000" then  
	  return("beqid   " & "   ra%" & todec(ra) & "   imm " & tohex(imm(0 to 3)) 
							       & tohex(imm(4 to 7))
		                                               & tohex(imm(8 to 11)) 
							       & tohex(imm(12 to 15)));
	elsif rd = "00101" then
    	  return("bgei   " & "   ra%" & todec(ra) & "   imm " & tohex(imm(0 to 3)) 
			   				      & tohex(imm(4 to 7))
							      & tohex(imm(8 to 11)) 
							      & tohex(imm(12 to 15)));
	elsif rd = "10101" then
	  return("beqid   " & "   ra%" & todec(ra) & "   imm " & tohex(imm(0 to 3)) 
							       & tohex(imm(4 to 7))
		                                               & tohex(imm(8 to 11)) 
							       & tohex(imm(12 to 15)));
	end if;

		
when "101110" =>
	return("bri");
    	when others =>
    	return("wrong Opcode");
    end case;
 
end;

------------------------------------------------------------------------------------------
-- This includes the print procedure
------------------------------------------------------------------------------------------


procedure print(s : string) is
    variable L1 : line;
begin
  L1:= new string'(s);	--'
--  write(L1, s);
  writeline(output,L1);
end;

end debug;
